FlutterThemez class

The entry point for FlutterThemez.

Constructors

FlutterThemez({Color? primaryColor, Color? secondaryColor, String? fontFamily, AppBarTheme? appBarTheme, BottomAppBarThemeData? bottomAppBarTheme, CheckboxThemeData? checkboxTheme, ChipThemeData? chipTheme, DividerThemeData? dividerTheme, ElevatedButtonThemeData? elevatedButtonTheme, FloatingActionButtonThemeData? floatingActionButtonTheme, IconThemeData? iconTheme, ListTileThemeData? listTileTheme, NavigationRailThemeData? navigationRailTheme, RadioThemeData? radioTheme, SnackBarThemeData? snackBarTheme, SwitchThemeData? switchTheme, TabBarThemeData? tabBarTheme, TextTheme? textTheme, bool? useMaterial3})
The entry point for FlutterThemez.
factory

Properties

appBarTheme AppBarTheme?
A theme for customizing AppBars.
final
bottomAppBarTheme BottomAppBarThemeData
A theme for customizing BottomAppBars.
final
checkboxTheme CheckboxThemeData
A theme for customizing Checkboxs.
final
chipTheme ChipThemeData
A theme for customizing Chips.
final
dividerTheme DividerThemeData
A theme for customizing Dividers.
final
elevatedButtonTheme ElevatedButtonThemeData
A theme for customizing ElevatedButtons.
final
floatingActionButtonTheme FloatingActionButtonThemeData?
A theme for customizing FloatingActionButtons.
final
fontFamily String
The font family for this theme.
final
hashCode int
The hash code for this object.
no setterinherited
iconTheme IconThemeData
A theme for customizing Icons.
final
listTileTheme ListTileThemeData
A theme for customizing ListTiles.
final
A theme for customizing NavigationRails.
final
primaryColor Color
The primary color for this theme.
final
radioTheme RadioThemeData
A theme for customizing Radios.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
The secondary color for the theme.
final
snackBarTheme SnackBarThemeData?
A theme for customizing SnackBars.
final
switchTheme SwitchThemeData
A theme for customizing Switchs.
final
tabBarTheme TabBarThemeData?
A theme for customizing TabBars.
final
textTheme TextTheme?
A theme for customizing Texts.
final
useMaterial3 bool
Whether to use Material Design 3
final

Methods

dark() ThemeData
The entry point for FlutterThemez.
light() ThemeData
The entry point for FlutterThemez.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited